@@ -34,10 +34,14 @@ require_once('../include/sendmail.php');
 register_globals_off();
 
 extract(sane_import('post',
-  array('update', 'form_id',
-        'form_loginname', 'form_pw', 'form_pw2', 'form_realname', 'form_email',
-        'form_year',
-        'form_usepam')));
+  [
+    'hash' => 'form_id',
+    'name' => 'form_loginname',
+    'pass' => ['form_pw', 'form_pw2', 'form_realname', 'form_email'],
+    'digits' => 'form_year',
+    'true' => ['update', 'form_usepam']
+  ]
+));
 
 $form_email = preg_replace ('/\s/', '', $form_email);
 
@@ -315,9 +319,8 @@ _("In what year was the GNU project announced? [<a href='%s'>hint</a>]"),
         at this site (this requires your new login name to be the
         same as the AFS account name):")."</p>\n";
 
-        print '<p>&nbsp;&nbsp;&nbsp;<input type="checkbox"
-        name="form_usepam" value="1" > '._('use AFS based authentication')
-              ."</p>\n";
+        print '<p>&nbsp;&nbsp;&nbsp;' . form_checkbox ('form_usepam', 0)
+          . _('use AFS based authentication') . "</p>\n";
       }
     print form_footer();
   }
