@@ -64,8 +64,21 @@ function form_input ($type, $name, $value="", $extra=false)
   if ($type == 'hidden' || $type == 'submit' || $type == 'radio')
     $id_attr = '';
 
-  return '
-    <input type="'.$type.'"'.$id_attr.' name="'.$name.'" '.$value.$extra.' />';
+  return "<input type=\"$type\"$id_attr name=\"$name\" $value$extra />";
+}
+
+function form_checkbox ($name, $is_checked = 0, $attr = [])
+{
+  $extra = '';
+  if ($is_checked)
+    $extra .= ' checked="checked"';
+  if (!empty ($attr))
+    foreach ($attr as $k => $v)
+      $extra .= " $k=\"$v\"";
+  $val = '1';
+  if (isset ($attr['value']))
+    $val = '';
+  return form_input ('checkbox', $name, $val, $extra);
 }
 
 # Special input: textarea.
@@ -124,7 +137,7 @@ function form_check ($form_id)
   form_check_nobot();
 
   if (user_getid() == 0
-      && (!preg_match('/^[a-z0-9]*$/', $form_id)))
+      && (!preg_match('/^[a-f0-9]*$/', $form_id)))
     {
       fb(_("Unrecognized unique form_id"), 1);
       return 0;
@@ -171,7 +184,7 @@ function form_clean ($form_id)
 # dumbuser-compliant.
 function form_check_nobot ()
 {
-  extract(sane_import('request', array('website')));
+  extract(sane_import('request', ['pass' => 'website']));
   if ($website != "" && $website != "http://")
     {
       # Not much explanation on the reject, since we are hunting spammers.
