@@ -43,7 +43,7 @@ function html_show_boxoptions ($legend, $content, $form_opening=0, $submit=0)
 <fieldset id="options" class="boxoptions">
 <legend>';
 
-  extract(sane_import('request', array('boxoptionwanted')));
+  extract(sane_import('request', ['true' => 'boxoptionwanted']));
 
   if ($boxoptionwanted != 1)
     $boxoptionwanted = 0;
@@ -869,11 +869,10 @@ function html_select_theme_box ($input_name="user_theme", $current=0)
 
 function html_build_checkbox ($name, $is_checked=0, $title="")
 {
-  print  '<input type="checkbox" '.html_title_attr ($title).' id="'.$name
-         .'" name="'.$name.'" value="1"';
-  if ($is_checked)
-    print ' checked="checked"';
-  print ' />';
+  $attr = [];
+  if ($title !== '')
+    $attr['title'] = $title;
+  print  form_checkbox ($name, $is_checked, $attr);
 }
 
 # Catch all header functions.
@@ -881,13 +880,13 @@ function html_header($params)
 {
   global $HTML, $feedback;
   print $HTML->header($params);
-  print html_feedback_top($feedback);
+  print html_feedback_top();
 }
 
 function html_footer($params)
 {
   global $HTML, $feedback;
-  print html_feedback_bottom($feedback);
+  print html_feedback_bottom();
   $HTML->footer($params);
 }
 
