@@ -111,12 +111,12 @@ print '</span>';
 print $HTML->box_bottom();
 print "<br />\n";
 
-# As all projects use the cookbook, this is accurate is all cases.
-print $HTML->box_top(_("Search in this Group"));
-print '<span class="smaller">';
-print search_box('','');
-print '</span>';
-print $HTML->box_bottom();
+if (search_has_group_anything_to_search ($group_id))
+  {
+    print $HTML->box_top (_("Search in this Group"));
+    print '<span class="smaller">' . search_box () . '</span>';
+    print $HTML->box_bottom ();
+  }
 
 print '
 </div><!-- end indexright -->
@@ -381,10 +381,9 @@ function open_vs_total_items ($url, $group_id, $artifact)
 
 # Communication.
 if ($GLOBALS['sys_unix_group_name'] == $group
-    || $project->Uses("support")
-    || $project->Uses("forum")
-    || $project->usesMail()
-    || people_project_jobs_rows($group_id) != 0)
+    || $project->Uses ("support") || $project->Uses ("forum")
+    || $project->Uses ("mail")
+    || people_project_jobs_rows ($group_id) != 0)
   {
     print $HTML->box_top(_("Communication Tools"));
     $i = 1;
@@ -439,7 +438,7 @@ if ($GLOBALS['sys_unix_group_name'] == $group
         $i++;
       }
 
-    if ($project->usesMail())
+    if ($project->Uses ("mail"))
       {
         specific_makesep();
         $url = $project->getArtifactUrl("mail");
