@@ -162,7 +162,7 @@ function sitemenu_search()
   global $HTML,$group_id;
   $HTML->menuhtml_top(_("Search"));
   print '       <li class="menusearch">';
-  print search_box("", "menu");
+  print search_box("", "sitewide");
   print '       </li><!-- end menusearch -->';
   $HTML->menuhtml_bottom();
 }
@@ -422,11 +422,7 @@ function sitemenu_help()
   global $HTML;
   $HTML->menuhtml_top(_("Site Help"));
 
-  $HTML->menu_entry($GLOBALS['sys_home'].'cookbook/?group='
-                    .$GLOBALS['sys_unix_group_name'],
-                    _("User Docs: Cookbook"),
-                    1,
-                    _("Recipes dedicated to any users, including Project Admins"));
+  $HTML->menu_entry('/maintenance/FrontPage/', _('User Docs: FAQ'));
   $HTML->menu_entry($GLOBALS['sys_home'].'userguide/',
                     _("User Docs: In Depth Guide"),
                     1,
