@@ -7,7 +7,7 @@
 # Copyright (C) 2001-2002 Laurent Julliard, CodeX Team, Xerox
 # Copyright (C) 2003-2006 Mathieu Roy <yeupou--gnu.org>
 # Copyright (C) 2003-2006 Yves Perrin <yves.perrin--cern.ch>
-# Copyright (C) 2018, 2019, 2020 Ineiev
+# Copyright (C) 2018, 2019, 2020, 2022 Ineiev
 #
 # This file is part of Savane.
 #
@@ -152,121 +152,95 @@ function trackers_data_show_notification_settings($group_id, $tracker_name,
 {
   $grtrsettings = &trackers_data_get_notification_settings($group_id,
                                                            $tracker_name);
-  if (!(user_ismember($group_id, 'A')))
+  if (!(user_ismember ($group_id, 'A')))
     return;
+  $check = ' checked="checked" ';
+  $cat_ck = $glob_ck = $both_ck ='';
   if ($grtrsettings['glnotif'] == 0)
-    {
-      $categoryradio = "checked";
-      $globalradio = "";
-      $bothradio = "";
-    }
+    $cat_ck = $check;
   if ($grtrsettings['glnotif'] == 1)
-    {
-      $categoryradio = "";
-      $globalradio = "checked";
-      $bothradio = "";
-    }
+    $glob_ck = $check;
   if ($grtrsettings['glnotif'] == 2)
-    {
-      $categoryradio = "";
-      $globalradio = "";
-      $bothradio = "checked";
-    }
-  if ($grtrsettings['nb_categories'] > 0)
+    $both_ck = $check;
+  $cat_n = $grtrsettings['nb_categories'];
+  if ($cat_n > 0)
     {
       if ($show_intro_msg != 0)
           print '<p>'
-. sprintf(
-# TRANSLATORS: the argument is tracker name (like bugs, support requests, tasks).
-         _("As a project administrator you must decide if the list of persons
-to be systematically notified on new %s submissions (and possibly updates)
-depend on the categories or not and you must provide the corresponding email
-addresses (comma separated list)."),
-           utils_get_tracker_name($tracker_name))
-. "</p>\n";
-      print '
-           <input type="radio" name="' . $tracker_name
-. '_notif_scope" value="global" ' . $globalradio
-. ' />&nbsp;&nbsp;<span class="preinput">'
-. _("Notify persons in the global list only") . '</span><br />
-          <input type="radio" name="' . $tracker_name
-. '_notif_scope" value="category" ' . $categoryradio
-. ' />&nbsp;&nbsp;<span class="preinput">'
-. _("Notify persons in the category related list instead of the global list")
-. '</span><br />
-          <input type="radio" name="' . $tracker_name
-. '_notif_scope" value="both" ' . $bothradio
-. ' />&nbsp;&nbsp;<span class="preinput">'
-. _("Notify persons in the category related list in addition to the global list")
-. '</span><br />
+            . _("Here you can decide whether the lists "
+                . "of persons to be notified on new submissions and updates "
+                . "depend on item categories, and provide the respective "
+                . "email addresses (comma-separated list).")
+             . "</p>\n";
+      print "<input type='radio' name=\"${tracker_name}_notif_scope\" "
+        . "value='global'$glob_ck/>&nbsp;&nbsp;<span class='preinput'>"
+        . _("Notify persons in the global list only") . "</span><br />\n"
+        . "<input type='radio' name=\"${tracker_name}_notif_scope\" "
+        . "value='category'$cat_ck/>&nbsp;&nbsp;<span class='preinput'>"
+        . _("Notify persons in the category related list "
+            . "instead of the global list") . "</span><br />\n"
+        . "<input type='radio' name=\"${tracker_name}_notif_scope\" "
+        . "value='both'$both_ck/>&nbsp;&nbsp;<span class='preinput'>"
+        . _("Notify persons in the category related list in addition to "
+            . "the global list")
+        . "</span><br />\n<h2>" . _("Category related lists") . "</h2>\n";
+      print "<input type='hidden' name=\"${tracker_name}_nb_categories\" "
+        . "value=\"$cat_n\" />\n";
 
-          <h2>' . _("Category related lists") . "</h2>\n";
-      print '<input type="hidden" name="' . $tracker_name
-. '_nb_categories" value="' . $grtrsettings['nb_categories'] . '" />';
-
-      for ($i=0; $i < $grtrsettings['nb_categories'] ; $i++)
+      for ($i = 0; $i < $cat_n ; $i++)
         {
-          print '<input type="hidden" name="' . $tracker_name . '_cat_' . $i
-. '_bug_fv_id" value="' . $grtrsettings['category'][$i]['fv_id'] . '" />';
-          print '<span class="preinput"><label
-for="' . $tracker_name . '_cat_' . $i . '_email">'
-. $grtrsettings['category'][$i]['name']
-. '</span><br />
-&nbsp;&nbsp;<input type="text" id="' . $tracker_name . '_cat_' . $i
-. '_email" name="' . $tracker_name . '_cat_' . $i
-. '_email" value="' . $grtrsettings['category'][$i]['email']
-. '" size="50" maxlength="255" />
-          &nbsp;&nbsp;<span class="preinput">(
-          <input type="checkbox" id="' . $tracker_name . '_cat_' . $i
-. '_send_all_flag" name="' . $tracker_name . '_cat_'.$i
-. '_send_all_flag" value="1" '
-.  (($grtrsettings['category'][$i]['send_all_flag'])? 'checked="checked"': '')
-. ' /><label for="' . $tracker_name . '_cat_' . $i
-. '_send_all_flag"' . _("Send on all updates") . ')</label></span><br />
-';
+          $tr_cat = $tracker_name . '_cat_' . $i;
+          $cb_name = $tr_cat . '_send_all_flag';
+          $settings = $grtrsettings['category'][$i];
+          print '<input type="hidden" name="' . $tr_cat . '_bug_fv_id" value="'
+            . $settings['fv_id'] . '" />';
+          print "<span class='preinput'><label for=\"${tr_cat}_email\">"
+            . $settings['name']
+            . "</span><br />\n&nbsp;&nbsp;<input type='text' id=\""
+            . "${tr_cat}_email\" name=\"${tr_cat}_email\" value=\""
+            . htmlspecialchars ($settings['email'])
+            . "\" size='50' maxlength='255' />\n"
+            . "&nbsp;&nbsp;<span class='preinput'>("
+            . form_checkbox ($cb_name, $settings['send_all_flag'])
+            . "<label for=\"$cb_name\">" . _("Send on all updates")
+            . ")</label></span><br />\n";
         }
       print '<h2>' . _("Global list") . "</h2>\n";
     }
-  else
-    {
-      if ($show_intro_msg != 0)
-        print '<p>'
-. sprintf(
-# TRANSLATORS: the argument is tracker name (like bugs, support requests, tasks).
-         _("As a project administrator you must decide if the list of persons
-to be systematically notified on new %s submissions (and possibly updates)
-depend on the categories or not and you must provide the corresponding email
-addresses (comma separated list)."), utils_get_tracker_name($tracker_name))
-. "</p>\n";
-    }
+  elseif ($show_intro_msg != 0)
+    print '<p>'
+        . _("Here you can decide whether the lists "
+            . "of persons to be notified on new submissions and updates "
+            . "depend on item categories, and provide the respective "
+            . "email addresses (comma-separated list).")
+         . "</p>\n";
+
+$cb_name = $tracker_name . '_send_all_changes';
+$txt_name = $tracker_name . '_new_item_address';
   print '<span class="preinput"><label
-for="' . $tracker_name . '_new_item_address"' . _("Global List:")
-. '</label></span><br />
-&nbsp;&nbsp;<input type="text" id="' . $tracker_name
-. '_new_item_address" name="' . $tracker_name
-. '_new_item_address" value="' . $grtrsettings['glnewad']
-. '" size="50" maxlength="255" />
-      &nbsp;&nbsp;<span class="preinput">(<input type="checkbox" id="'
-. $tracker_name . '_send_all_changes" name="'
-. $tracker_name . '_send_all_changes" value="1" '
-. (($grtrsettings['glsendall'])?'checked':'')
-. '><label for="' . $tracker_name . '_send_all_changes"'
-. _("Send on all updates") . '</label>)</span>';
+for="' . $txt_name . '">' . _("Global List:")
+    . "</label></span><br />\n&nbsp;&nbsp;"
+    . "<input type='text' id=\"$txt_name\" name=\"$txt_name\""
+    . 'value="' . htmlspecialchars ($grtrsettings['glnewad'])
+    . '" size="50" maxlength="255" />
+      &nbsp;&nbsp;<span class="preinput">('
+    . form_checkbox ($cb_name, $grtrsettings['glsendall'])
+    . "<label for=\"$cb_name\">"
+    . _("Send on all updates") . '</label>)</span>';
 
   print '<h2>' . _("Private items exclude list") . "</h2>\n";
   if ($show_intro_msg != 0)
     print '<p>'
-. _("Addresses registered in this list will be excluded from default mail
+      . _("Addresses registered in this list will be excluded from default mail
 notification for private items.")
-. "</p>\n";
+      . "</p>\n";
 
-  print '<span class="preinput"><label
-for="' . $tracker_name . '_private_exclude_address"' . _("Exclude List:")
-. '</label></span><br />
-&nbsp;&nbsp;<input type="text" id="' . $tracker_name
-. '_private_exclude_address" name="' . $tracker_name
-. '_private_exclude_address" value="' . $grtrsettings['private_exclude']
-. '" size="50" maxlength="255" />' . "<br />\n";
+  $txt_name = $tracker_name . '_private_exclude_address';
+  print '<span class="preinput"><label for="' . $txt_name
+    . '">' . _("Exclude List:") . "</label></span><br />\n&nbsp;&nbsp;"
+    . "<input type='text' id=\"$txt_name\" name=\"$txt_name\" value=\""
+    . htmlspecialchars ($grtrsettings['private_exclude'])
+    . "\" size='50' maxlength='255' /><br />\n";
 }
 
 function trackers_data_post_notification_settings($group_id, $tracker_name)
@@ -283,11 +257,15 @@ function trackers_data_post_notification_settings($group_id, $tracker_name)
   $nb_categories_name = $tracker_name . "_nb_categories";
   $private_exclude_address_name = $tracker_name . "_private_exclude_address";
 
-  $in = sane_import('post', array($notif_scope_name,
-                                  $new_item_address_name,
-                                  $send_all_changes_name,
-                                  $nb_categories_name,
-                                  $private_exclude_address_name));
+  $in = sane_import ('post',
+    [
+      "strings" =>
+        [[$notif_scope_name, ['default' => 'global', 'category', 'both']]],
+      'pass' => [$new_item_address_name, $private_exclude_address_name],
+      'true' => $send_all_changes_name,
+      'digits' => $nb_categories_name
+    ]
+  );
 
   $notif_scope = $in[$notif_scope_name];
   $new_item_address = $in[$new_item_address_name];
@@ -295,20 +273,14 @@ function trackers_data_post_notification_settings($group_id, $tracker_name)
   $nb_categories = $in[$nb_categories_name];
   $private_exclude_address = $in[$private_exclude_address_name];
 
+  $notif_value = 1; # global by default.
   if (isset($notif_scope))
     {
-      if ($notif_scope != "global")
-        {
-          if ($notif_scope == "category")
-            $notif_value = 0;
-          if ($notif_scope == "both")
-            $notif_value = 2;
-        }
-      else
-        $notif_value = 1; # global only
+      if ($notif_scope == "category")
+        $notif_value = 0;
+      if ($notif_scope == "both")
+        $notif_value = 2;
     }
-  else
-    $notif_value = 1; # global only (scope not proposed = no categories)
 
 # Set global notification info for this group.
   $res_gl = db_autoexecute('groups',
@@ -332,13 +304,17 @@ function trackers_data_post_notification_settings($group_id, $tracker_name)
     {
       for ($i = 0; $i < $nb_categories; $i++)
         {
-          $current_fv_name = $tracker_name . "_cat_" . $i . "_bug_fv_id";
-          $current_email_name = $tracker_name . "_cat_" . $i . "_email";
-          $current_send_all_name = $tracker_name . "_cat_" . $i
-                                   . "_send_all_flag";
-          $in = sane_import('post', array($current_fv_name,
-                                          $current_email_name,
-                                          $current_send_all_name));
+          $tr_cat = $tracker_name . "_cat_" . $i;
+          $current_fv_name = $tr_cat . "_bug_fv_id";
+          $current_email_name = $tr_cat . "_email";
+          $current_send_all_name = $tr_cat . "_send_all_flag";
+          $in = sane_import('post',
+            [
+              'digits' => $current_fv_name,
+              'pass' => $current_email_name,
+              'true' => $current_send_all_name
+            ]
+          );
 
           $current_fv_id = $in[$current_fv_name];
           $current_email = $in[$current_email_name];
@@ -1043,20 +1019,19 @@ function trackers_data_copy_default_values($field, $group_id, $by_field_id=false
     }
 }
 
-function trackers_data_get_cached_field_value($field,$group_id,$value_id)
+function trackers_data_get_cached_field_value ($field, $group_id, $value_id)
 {
   global $BF_VALUE_BY_NAME;
 
-  if (!isset($BF_VALUE_BY_NAME[$field][$value_id]))
+  if (isset ($BF_VALUE_BY_NAME[$field][$value_id]))
+    return $BF_VALUE_BY_NAME[$field][$value_id];
+  $res = trackers_data_get_field_predefined_values ($field, $group_id);
+  while ($fv_array = db_fetch_array($res))
     {
-      $res = trackers_data_get_field_predefined_values ($field, $group_id,
-                                                        false, false, false);
-      while ($fv_array = db_fetch_array($res))
-        {
-          # $fv_array[0] has the value_id and [1] is the value
-          $BF_VALUE_BY_NAME[$field][$fv_array['value_id']] = $fv_array[1];
-        }
+      $BF_VALUE_BY_NAME[$field][$fv_array['value_id']] = $fv_array['value'];
     }
+  if (!isset ($BF_VALUE_BY_NAME[$field][$value_id]))
+    $BF_VALUE_BY_NAME[$field][$value_id] = null;
   return $BF_VALUE_BY_NAME[$field][$value_id];
 }
 
@@ -1384,25 +1359,36 @@ function trackers_data_get_followups ($item_id = false, $rorder = false)
   else
     $rorder = "ASC";
 
-  return db_execute("SELECT DISTINCT " . ARTIFACT . "_history.bug_history_id,"
-    . ARTIFACT . "_history.field_name," . ARTIFACT . "_history.old_value,"
-    . ARTIFACT . "_history.spamscore," . ARTIFACT . "_history.new_value,"
-    . ARTIFACT . "_history.date,user.user_name,user.realname,user.user_id,"
-    . ARTIFACT . "_field_value.value AS comment_type "
-    . "FROM " . ARTIFACT . "_history," . ARTIFACT . "_field_value,"
-    . ARTIFACT . "_field," . ARTIFACT . ",user "
-    . "WHERE " . ARTIFACT . "_history.bug_id = ? "
-    . "AND " . ARTIFACT . "_history.field_name = 'details' "
-    . "AND " . ARTIFACT . "_history.mod_by=user.user_id "
-    . "AND " . ARTIFACT . "_history.bug_id=" . ARTIFACT . ".bug_id "
-    . "AND " . ARTIFACT . "_history.type = " . ARTIFACT . "_field_value.value_id "
-    . "AND " . ARTIFACT . "_field_value.bug_field_id = "
-    . ARTIFACT . "_field.bug_field_id "
-    . "AND (" . ARTIFACT . "_field_value.group_id = "
-    . ARTIFACT . ".group_id OR " . ARTIFACT . "_field_value.group_id = '100') "
-    . "AND  " . ARTIFACT . "_field.field_name = 'comment_type_id' "
-    . "ORDER BY " . ARTIFACT . "_history.date $rorder",
-                    array($item_id));
+  $tracker = ARTIFACT;
+
+  return
+    db_execute ("
+      SELECT DISTINCT
+        bug_history_id, field_name, old_value, spamscore, new_value, date,
+        user_name, realname, user_id, value AS comment_type
+      FROM
+        (
+          SELECT
+            b.bug_history_id, b.field_name, b.old_value, b.spamscore,
+            b.new_value, b.date, b.mod_by, b.type, t.group_id AS grp,
+            u.user_name, u.realname, u.user_id
+          FROM ${tracker}_history b, ${tracker} t, user u
+          WHERE
+            t.bug_id = ? AND b.bug_id = t.bug_id
+            AND b.field_name = 'details' AND b.mod_by = u.user_id
+        ) bhi
+        LEFT JOIN
+        (
+          SELECT DISTINCT v.value, v.value_id, v.group_id
+          FROM ${tracker}_field_value v, ${tracker}_field f
+          WHERE
+            v.bug_field_id = f.bug_field_id
+            AND f.field_name = 'comment_type_id'
+        ) fv
+        ON bhi.type = fv.value_id AND bhi.grp = fv.group_id
+      ORDER BY date $rorder",
+      [$item_id]
+    );
 }
 
 function trackers_data_get_commenters($item_id)
@@ -2503,27 +2489,28 @@ function trackers_data_get_value($field, $group_id, $value_id,
   else
     $field_id = trackers_data_get_field_id($field);
 
-  # Look for project specific values first...
-  $result = db_execute("SELECT * FROM " . ARTIFACT . "_field_value "
-     . "WHERE  bug_field_id=? AND group_id=? AND value_id=?",
-     array($field_id, $group_id,
-           $value_id));
-  if ($result && db_numrows($result) > 0)
+  $sql = "SELECT * FROM " . ARTIFACT . "_field_value "
+    . "WHERE group_id=? AND value_id=?";
+  $args = [ $group_id, $value_id];
+  if ($field_id !== null)
     {
-      return db_result($result,0,'value');
+      $sql .= ' AND bug_field_id=?';
+      $args[] = $field_id;
     }
 
+  # Look for project specific values first...
+  $result = db_execute ($sql, $args);
+  if ($result && db_numrows($result) > 0)
+    return db_result ($result, 0, 'value');
+
   # ... if it fails, look for system wide default values (group_id=100)...
-  $result=db_execute("SELECT * FROM ".ARTIFACT."_field_value ".
-     "WHERE  bug_field_id=? AND group_id=100 ".
-     "AND value_id=?", array($field_id, $value_id));
-  if ($result && db_numrows($result) > 0)
-    {
-      return db_result($result,0,'value');
-    }
+  $args[0] = 100;
+  $result = db_execute ($sql, $args);
+  if ($result && db_numrows ($result) > 0)
+    return db_result ($result, 0, 'value');
 
   # No value found for this value id.
-  return $value_id . '(Error - Not Found)';
+  return $value_id . _('(Error - Not Found)');
 }
 
 # Show defined and site-wide responses.
@@ -2724,6 +2711,8 @@ function trackers_data_delete_file($group_id, $item_id, $file_id)
 function trackers_data_count_field_value_usage ($group_id, $field,
                                                 $field_value_value_id)
 {
+  if ($field == 'comment_type_id')
+    return 0;
   if (!preg_match('/^[a-z0-9_]+$/', $field))
     util_die('trackers_data_count_field_value_usage: invalid $field <em>'
              . htmlspecialchars($field) . '</em>');
