@@ -580,31 +580,6 @@ function trackers_multiple_field_box($field_name,
                                         $text_any,$show_value);
 }
 
-# Similar to trackers_multiple_field_box except that it will use checkboxes
-# instead of a multiple select field. Multiple select field is nice for
-# expert users, but it is not simple user-friendly, unlike checkboxes.
-function trackers_multiple_field_box2 ($field_name,
-                                       $box_name='',
-                                       $group_id,
-                                       $checked=false,
-                                       $show_none=false,
-                                       $text_none='None',
-                                       $show_any=false,
-                                       $text_any='Any',
-                                       $show_value=false)
-{
-  if (!$group_id)
-    return _("Internal error: no group id");
-  $result = trackers_data_get_field_predefined_values($field_name,$group_id,
-                                                      $checked);
-  if ($box_name == '')
-    {
-      $box_name = $field_name.'[]';
-    }
-  return html_build_checkbox($result,$box_name,$checked,6,$show_none,
-                             $text_none, $show_any,$text_any,$show_value);
-}
-
 # Returns the list of field names in the HTML Form corresponding to a
 # field used by this project
 function trackers_extract_field_list($post_method=true)
@@ -1020,41 +995,6 @@ function trackers_mail_followup ($item_id,$more_addresses=false,$changes=false,
   $group_id = db_result($result,0,'group_id');
 
   unset($content_type);
-  # CERN SPECIFIC (at least for now) BEGIN
-  # Maybe later we ll implement a way to select mail templates, or prepared
-  # mail format (like: text / html).
-  # But it will have to be done in a well planned way that take into account
-  # necessary cases and is not encumbered by very very specific things.
-  # Until this happen, cern will use its own functions to deals with notif.
-  # Indeed, this part will maintained and modified by CERN only.
-  #
-  # To ease maintainance, such specific things should usually not be added.
-  # Please write to savane-dev if you intend to make such changes.
-  # The upstream code cannot be cluttered by tons of things like that.
-  # This is a one time exception, or almost, needed because this cannot
-  # be directly merged in a generic way right now.
-  if ($GLOBALS['sys_default_domain'] == "savannah.cern.ch"
-      || !empty($GLOBALS['sys_debug_cerntest']))
-    {
-      $content_type = group_get_preference($group_id, "notif_content");
-      if ($content_type == "")
-        {
-          # By default select maximum.
-          $content_type = '2';
-        }
-
-      # Now, if the content type is 0, go on with Savane standard notif.
-      # If it's something else, use trackers_mail_followup_cernspecifichack().
-      if ($content_type > 0)
-        {
-          return trackers_mail_followup_cernspecifichack($group_id,$bug_href,
-                                                         $result,$content_type,
-                                                         $item_id,$more_addresses,
-                                                         $changes,
-                                                         $force_exclude_list);
-        }
-    }
-  # CERN SPECIFIC (at least for now) END
   # Content of the mail must not be translated.
   $body = '';
 
@@ -1174,8 +1114,8 @@ function trackers_attach_several_files($item_id, $group_id, &$changes)
   $filenames = array();
   for ($i = 1; $i < 5; $i++)
     $filenames[] = "input_file$i";
-  $files = sane_import('files', $filenames);
-  extract(sane_import('post', array('file_description')));
+  $files = sane_import('files', ['pass' => $filenames]);
+  extract(sane_import('post', ['specialchars' => 'file_description']));
   foreach ($files as $file)
     {
       if ($file['error'] != UPLOAD_ERR_OK)
@@ -1296,7 +1236,7 @@ after escaping characters as required.",
       'artifact' => ARTIFACT,
       'submitted_by' => $user_id,
       'date' => time(),
-      'description' => htmlspecialchars($file_description),
+      'description' => $file_description,
       'filename' => $input_file_name,
       'filesize' => $input_file_size,
       'filetype' => $input_file_type
@@ -1355,7 +1295,7 @@ function trackers_insert_cc($item_id,$cc,$added_by,$comment,$date)
       'bug_id' => $item_id,
       'email' => $cc,
       'added_by' => $added_by,
-      'comment' => htmlspecialchars($comment),
+      'comment' => $comment,
       'date' => $date
     ), DB_AUTOQUERY_INSERT);
 
@@ -1497,7 +1437,7 @@ function trackers_delete_cc_by_user ($item_id, $user_id)
   return (db_numrows($result) >= 1);
 }
 
-function trackers_delete_dependancy ($group_id, $item_id, $item_depends_on,
+function trackers_delete_dependency ($group_id, $item_id, $item_depends_on,
                                      $item_depends_on_artifact, &$changes)
 {
   # Can be done only by at least technicians.
@@ -1520,18 +1460,16 @@ function trackers_delete_dependancy ($group_id, $item_id, $item_depends_on,
       return false;
     }
   fb(_("Dependency Removed."));
-  trackers_data_add_history("Dependencies",
-                            "Removed dependency to "
-                            .$item_depends_on_artifact." #"
-                            .$item_depends_on,
-                            "-",
-                            $item_id,
-                            0,0,1);
-  trackers_data_add_history("Dependencies",
-                            "Removed dependency from ".ARTIFACT." #".$item_id,
-                            "-",
-                            $item_depends_on,
-                            0,0,1);
+  trackers_data_add_history (
+    "Dependencies",
+    "Removed dependency to $item_depends_on_artifact #$item_depends_on",
+    "-", $item_id, 0, 0, 1
+  );
+  trackers_data_add_history (
+    "Dependencies",
+    "Removed dependency from " . ARTIFACT . " #$item_id",
+    "-", $item_depends_on, 0, $item_depends_on_artifact, 1
+  );
 
   $changes['Dependency Removed']['add'] = $item_depends_on_artifact." #"
                                           .$item_depends_on;
@@ -1646,18 +1584,17 @@ function trackers_criteria_list_to_text($criteria_list, $url)
 
       foreach ($arr as $crit)
         {
-          $morder .= ($morder ? ",".$crit : $crit);
-          $attr = str_replace('>','',$crit);
-          $attr = str_replace('<','',$attr);
-          $morder = htmlspecialchars($morder);
+          $morder .= ($morder? ",$crit": $crit);
+          $attr = str_replace('>', '', $crit);
+          $attr = str_replace('<', '', $attr);
           $so = trackers_sorting_order ($crit);
-          $arr_text[] = '<a href="'.$url.'&amp;morder='.$morder.'#results">'
+          $arr_text[] = '<a href="' . "$url&amp;morder=$morder" . '#results">'
              .trackers_data_get_label($attr).'</a><img class="icon" src="'
              .$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/arrows/'
              .$so['image'].'.png" border="0" alt="'.$so['text'].'" />';
         }
     }
-  return join(' &gt; ',$arr_text);
+  return join(' &gt; ', $arr_text);
 }
 
 function trackers_build_match_expression($field, &$to_match)
@@ -1831,526 +1768,4 @@ function trackers_get_msgid ($artifact, $item_id, $latest="")
     }
   return $list;
 }
-
-############## NASTY HACK
-
-  # CERN SPECIFIC (at least for now) BEGIN '
-  # Maybe later we ll implement a way to select mail templates, or prepared
-  # mail format (like: text / html).
-  # But it will have to be done in a well planned way that take into account
-  # necessary cases and is not encumbered by very very specific things.
-  # Until this happen, cern will use its own functions to deals with notif.
-  # Indeed, this part will maintained and modified by CERN only.
-  #
-  # To ease maintainance, such specific things should usually not be added.
-  # Please write to savane-dev if you intend to make such changes.
-  # The upstream code cannot be cluttered by tons of things like that.
-  # This is a one time exception, or almost, needed because this cannot
-  # be directly merged in a generic way right now.
-function trackers_mail_followup_cernspecifichack ($group_id, $bug_href,
-   $result,$content_type, $item_id, $more_addresses=false, $changes=false,
-   $force_exclude_list=false)
-{
-  global $sys_datefmt;
-
-  # MUST BE DEFINED HERE, dont ask me why.
-  $subject = utils_unconvert_htmlspecialchars(db_result($result,0,'summary'));
-
-  if ($content_type == '2')
-    {   # for now means CERN present format
-                               # (last + overview + all followups)
-
-      $body = "This is an automated notification sent by "
-              .$GLOBALS['sys_name']. ".
-It relates to:\n\t\t".ARTIFACT." #".$item_id.", project "
-              .group_getname($group_id)."\n";
-      if ($changes)
-        {
-          $body .=
-"\n==============================================================================
- LATEST MODIFICATIONS of ".ARTIFACT." #".$item_id.":
-==============================================================================\n\n";
-
-          ### format_item_changes of savane 1.0.6
-          # FIXME: strange, with %25s it does not behave exactly like
-          # trackers_field_label_display.
-          $fmt = "%24s: %23s => %-23s\n";
-
-          $separator = "\n    _______________________________________________________\n\n";
-
-          # Process most of the fields.
-          reset($changes);
-
-          foreach ($changes as $field => $h)
-            {
-              # If both removed and added items are empty skip - Sanity check.
-              if (!$h['del'] && !$h['add'])
-                continue;
-
-              if ($field == "details" || $field == "attach")
-                continue;
-
-              $label = trackers_data_get_label($field);
-              if (!$label)
-                $label = $field;
-              $out .= sprintf($fmt, $label, $h['del'],$h['add']);
-            }
-          if ($out)
-            {
-              $out = "Update of ".utils_get_tracker_prefix(ARTIFACT)." #"
-                     .$item_id
-                     ." (project ".group_getunixname($group_id)."):\n\n".$out;
-            }
-          # Process special cases: follow-up comments.
-          if ($changes['details'])
-            {
-              if ($out)
-                $out .= $separator;
-
-              $out_com = "Follow-up Comment #"
-                         .db_numrows(trackers_data_get_followups($item_id));
-              if (!$out)
-                {
-                  $out_com .= ", ".utils_get_tracker_prefix(ARTIFACT)." #"
-                              .$item_id
-                              ." (project ".group_getunixname($group_id).")";
-                }
-
-              $out_com .= ":\n\n";
-              if ($changes['details']['type'] != 'None'
-                  && $changes['details']['type'] != '(Error - Not Found)')
-                {
-                  $out_com .= '['.$changes['details']['type']."]\n";
-                }
-              $out_com .=
-                utils_unconvert_htmlspecialchars($changes['details']['add']);
-              unset($changes['details']);
-
-              $out .= $out_com;
-            }
-
-          # Process special cases: file attachment.
-          if ($changes['attach'])
-            {
-              if ($out)
-                $out .= $separator;
-
-              $out_att = "Additional Item Attachment";
-              if (!$out)
-                {
-                  $out_att .= ", ".utils_get_tracker_prefix(ARTIFACT)." #"
-                              .$item_id
-                              ." (project ".group_getunixname($group_id).")";
-                }
-              $out_att .= ":\n\n";
-              $out_att .= sprintf("File name: %-30s Size:%d KB\n",
-                                  $changes['attach']['name'],
-                                  intval($changes['attach']['size']/1024) );
-              $out_att .= $changes['attach']['description']."\n".'<'
-                          .$changes['attach']['href'].'>';
-              unset($changes['attach']);
-
-              $out .= $out_att;
-            }
-
-          $body .= $out;
-          ### format_item_changes of savane 1.0.6
-
-          $body .= "\n";
-        }
-
-      $body .=
-"\n==============================================================================
- OVERVIEW of ".ARTIFACT." #".$item_id.":
-==============================================================================\n
-URL:\n  <".$bug_href.">\n\n";
-      $body .= trackers_field_display('summary', $group_id,
-                                      db_result($result,0,'summary'),
-                                      false,true,true,true)."\n";
-      $body .= sprintf("%25s", "Project:").' '.group_getname($group_id)."\n";
-      $body .= trackers_field_display('submitted_by', $group_id,
-                                      db_result($result,0,'submitted_by'),
-                                      false,true,true,true)."\n";
-      $body .= trackers_field_display('date', $group_id,
-                                       db_result($result,0,'date'),
-                                      false,true,true,true)."\n";
-
-      # All other regular fields now
-      $i=0;
-      while ($field_name = trackers_list_all_fields())
-        {
-          # If the field is a special field or if not used by his project
-          # then skip it. Otherwise print it in ASCII format.
-          if (!trackers_data_is_special($field_name)
-              && trackers_data_is_used($field_name))
-            {
-
-              $body .= trackers_field_display($field_name,
-                                              $group_id,
-                                              db_result($result,0,$field_name),
-                                              false,
-                                              true,
-                                              true,
-                                              true);
-              $i++;
-              $body .= "\n";
-            }
-        }
-      $body .= "\n";
-
-      # Now display other special fields.
-      $body .= "    _______________________________________________________\n\n"
-               .trackers_field_display('details',
-                                       $group_id,
-                                       db_result($result,0,'details'),
-                                       true,true,true,true);
-      # Then output the history of bug details from newest to oldest.
-      $body .= "\n\n";
-      # format_item_details($item_id, $group_id, true); of savane 1.0.6
-      $result=trackers_data_get_followups($item_id);
-      $rows=db_numrows($result);
-
-      # No followup comment -> return now.
-      if ($rows > 0)
-        {
-          unset($out);
-          $out .= "    _______________________________________________________\n
-Follow-up Comments:\n\n";
-
-          # Loop throuh the follow-up comments and format them.
-          for ($i=$rows-1; $i >= 0; $i--)
-            {
-              $comment_type = db_result($result, $i, 'comment_type');
-              if ($comment_type == 'None')
-                $comment_type = '';
-              else
-                $comment_type = '['.$comment_type.']';
-
-              $fmt = "\n-------------------------------------------------------\n"
-                 ."Date: %-30sBy: %s\n";
-              if ($comment_type)
-                $fmt .= "%s\n%s";
-              else
-                $fmt .= "%s%s";
-              $fmt .= "\n";
-              # I wish we had sprintf argument swapping in PHP3 but
-              # we dont so do it the ugly way...
-
-              if (db_result($result, $i, 'realname'))
-                {
-                  $name = db_result($result, $i, 'realname')." <"
-                          .db_result($result, $i, 'user_name').">";
-                }
-              else
-                $name = "Anonymous"; # must no be translated, part of mails notifs
-              $out .= sprintf($fmt,
-                              utils_format_date(db_result($result, $i, 'date')),
-                              $name,
-                              $comment_type,
-                              utils_unconvert_htmlspecialchars(
-                                db_result($result, $i, 'old_value'))
-                              );
-
-            }
-           $out .=  "\n\n\n";
-           $body .= $out;
-        }
-      # format_item_details($item_id, $group_id, true); of savane 1.0.6 end
-
-      # Then output the CC list.
-      $body .= "\n\n";
-      # format_item_cc_list($item_id, $group_id, true); of savane 1.0.6
-      $result=trackers_data_get_cc_list($item_id);
-      $rows=db_numrows($result);
-
-      # No file attached -> return now.
-      if ($rows > 0)
-        {
-          unset($out);
-          $out .=
-"    _______________________________________________________\n\n"
-                  ."Carbon-Copy List:\n\n";
-          $fmt = "%-35s | %s\n";
-          $out .= sprintf($fmt, 'CC Address', 'Comment');
-          $out .=
-"------------------------------------+-----------------------------\n";
-
-          # Loop through the cc and format them.
-          for ($i=0; $i < $rows; $i++)
-            {
-              $email = db_result($result, $i, 'email');
-              $item_cc_id = db_result($result, $i, 'bug_cc_id');
-
-              # If the CC is a user point to its user page.
-              # Do not build mailto, we do not need to help spammers.
-              $res_username = user_get_result_set_from_unix($email);
-              if ($res_username && (db_numrows($res_username) == 1))
-                $href_cc = utils_user_link($email);
-              else
-                $href_cc = $email;
-
-              $out .= sprintf($fmt, $email, db_result($result, $i, 'comment'));
-            }
-          $out .= "\n";
-          $body .= $out;
-        }
-      # format_item_cc_list($item_id, $group_id, true); of savane 1.0.6 end
-
-      # Then output the history of bug details from newest to oldest.
-      $body .= "\n\n";
-      # format_item_attached_files of savane 1.0.6
-      $result=trackers_data_get_attached_files($item_id);
-      $rows=db_numrows($result);
-
-      # No file attached -> return now.
-      if ($rows > 0)
-        {
-          unset($out);
-          $out .=
-"    _______________________________________________________\n
-File Attachments:\n\n";
-          $fmt = "\n-------------------------------------------------------\n"
-          ."Date: %s  Name: %s  Size: %s   By: %s\n%s\n%s";
-          # Loop throuh the attached files and format them.
-
-          for ($i=0; $i < $rows; $i++)
-            {
-              $item_file_id = db_result($result, $i, 'file_id');
-              $href = $GLOBALS['sys_home'] . ARTIFACT
-                      . "/download.php?file_id=$item_file_id";
-
-              $out .= sprintf($fmt,
-                              utils_format_date(db_result($result, $i, 'date')),
-                              db_result($result, $i, 'filename'),
-                              utils_filesize(0, intval(db_result($result, $i,
-                                                             'filesize'))),
-                              db_result($result, $i, 'user_name'),
-                              db_result($result, $i, 'description'),
-                              '<https://' . $GLOBALS['sys_default_domain']
-                              . utils_unconvert_htmlspecialchars($href) . '>');
-            }
-          $out .= "\n";
-          $body .= $out;
-        }
-      # format_item_attached_files of savane 1.0.6 end
-      # Finally output the message trailer.
-      $body .=
-"\n==============================================================================
-
-This item URL is:";
-      $body .= "\n  <".$bug_href.">";
-    }
-
-  if ($content_type == '1')
-    {   # For now means ROOT wishes (UGLY ... I know!).
-      $body = "";
-      $was_new_item = false;
-
-      if (user_isloggedin())
-        $body .= "Posted by: ".user_getrealname($user_id).' <'
-                 .user_getname($user_id).">";
-      else
-        $body .= "Posted by an anonymous user";
-      $body .= "\n";
-      $body .= "Related to: [".group_getname($group_id)." ".ARTIFACT." #".$item_id
-               ."] "
-               .utils_unconvert_htmlspecialchars(db_result($result,0,'summary'))
-               ."\n";
-      $body .= "URL: <".$bug_href.">\n\n";
-
-      if ($changes)
-        {
-          #Process special cases first: follow-up comment.
-          $fmt = "%s: %23s -> %-23s\n";
-          $was_followup = false;
-          if ($changes['details'])
-            {
-              $body .= "Follow-up Comment:\n\n";
-              if ($changes['details']['type'] != 'None'
-                  && $changes['details']['type'] != '(Error - Not Found)')
-                {
-                  $body .= '['.$changes['details']['type']."]\n";
-                }
-              $body .=
-                utils_unconvert_htmlspecialchars($changes['details']['add']);
-              $body .= "\n";
-              unset($changes['details']);
-              # Set flag to skip output of this followup comment at the end.
-              $was_followup = true;
-            }
-        }
-      else
-        {
-          # If new submission start with description.
-          $body .= trackers_field_display('details',
-                                           $group_id,
-                                           db_result($result,0,'details'),
-                                           true,true,true,true);
-          $body .= "\n";
-          # Set flag to skip output of original submission at the end.
-          $was_new_item = true;
-        }
-
-      if ($changes)
-        {
-          # Process special cases first: bug file attachment.
-          if ($changes['attach'])
-            {
-              $body .= sprintf("Attachment of file: %s   Size:%d KB  ",
-                         $changes['attach']['name'],
-                         intval($changes['attach']['size']/1024) );
-              $body .= $changes['attach']['description']."\n".'<'
-                       .$changes['attach']['href'].'>';
-              unset($changes['attach']);
-              $body .= "\n";
-            }
-
-          # All the rest of the fields now.
-          reset($changes);
-          if (count($changes))
-            {
-              $body .= "\n";
-
-              foreach ($changes as $field => $h)
-                {
-                  # If both removed and added items are empty skip - Sanity check.
-                  if (!$h['del'] && !$h['add'])
-                    continue;
-                  $label = trackers_data_get_label($field);
-                  if (!$label)
-                   $label = $field;
-                  $off = sprintf("%d", 23-strlen($label)-2);
-                  $fmt = "%s: %".$off."s -> %-23s\n";
-                  $body .= sprintf($fmt, $label, $h['del'],$h['add']);
-                }
-            }
-          else
-            $body .= "\n";
-          $body .= "\n";
-        }
-      else
-        $body .= "\n";
-
-      $body .= trackers_field_display('submitted_by', $group_id,
-                                      db_result($result,0,'submitted_by'),
-                                     false,true,true,true,false,'',false,'',false,
-                                     false,-3)."\n";
-
-      # All other regular fields now.
-      $i=0;
-      while ($field_name = trackers_list_all_fields())
-        {
-          # If the field is a special field or if not used by his project
-          # then skip it. Otherwise print it in ASCII format.
-          if (!trackers_data_is_special($field_name)
-              && trackers_data_is_used($field_name))
-            {
-              $body .= trackers_field_display($field_name, $group_id,
-                                              db_result($result,0,$field_name),
-                                              false, true, true, true, false,
-                                              '',false,'',false,false,-3);
-              $i++;
-              $body .= "\n";
-            }
-        }
-
-      # Then output the history of bug details from newest to oldest.
-      $fu_result=trackers_data_get_followups($item_id);
-      $fu_rows=db_numrows($fu_result);
-      if ($fu_rows > 0)
-        {
-          # Loop throuh the follow-up comments and format them.
-          $fmt = "\n-----Reply from %s on %s-----\n%s\n";
-          for ($i=$fu_rows-1; $i >= 0; $i--)
-            {
-              # Prevent output of most recent if already shown.
-              if ($was_followup && ($i == $fu_rows-1))
-                continue;
-              if (db_result($fu_result, $i, 'realname'))
-                $name = db_result($fu_result, $i, 'realname')." <"
-                        .db_result($fu_result, $i, 'user_name').">";
-              else
-                $name = "Anonymous"; # Must no be translated, part of mails notifs.
-              if (user_get_timezone())
-                $tz = ' ('.user_get_timezone().')';
-              else
-                $tz = '';
-              $body .= sprintf($fmt, $name,
-                               utils_format_date(db_result($fu_result,
-                                                           $i, 'date')).$tz,
-                               utils_unconvert_htmlspecialchars(
-                                 db_result($fu_result, $i, 'old_value'))
-                              );
-            }
-        }
-
-      if (!$was_new_item)
-        {
-          # Display Original Submission.
-          $body .= "\n  -----Original Message-----"
-                   .trackers_field_display('details', $group_id,
-                                           db_result($result,0,'details'),
-                                           true,true,true,true);
-        }
-    }
-
-  # See who is going to receive the notification.
-  # Plus append any other email given at the end of the list.
-  $arr_addresses = trackers_build_notification_list($item_id,$group_id,
-                                                    $changes);
-  $to = join(',',$arr_addresses);
-# CERN SPECIFIC HACK
-  $from = '"noreply ['.user_getrealname(0,0).']" <'
-          .$GLOBALS['sys_mail_replyto'].'@'.$GLOBALS['sys_mail_domain'].'>';
-
-# Replace usernames with user_ids (as expected by sendmail_mail).
-  $repl_addresses = '';
-
-  # -YPE- necessary because explode returns a one element array in case
-  # it has to explode an empty string and this screws the code later on.
-  if ($more_addresses != "")
-    {
-      $more_addr_arr = explode(',',$more_addresses);
-
-      foreach ($more_addr_arr as $maddr)
-        {
-          $maddr = str_replace (" ", "", $maddr);
-          if (validate_email($maddr))
-            $repl_addresses .= ($repl_addresses ? ',':'').$maddr;
-          else
-            {
-              $maddr_user_id = user_getid($maddr);
-              if (user_exists($maddr_user_id))
-                $repl_addresses .= ($repl_addresses ? ',':'').$maddr_user_id;
-              else
-                $repl_addresses .= ($repl_addresses ? ',':'').$maddr;
-            }
-        } # while (current ($more_addr_arr) !== FALSE)
-    }
-
-  if ($repl_addresses)
-    $to .= ($to ? ',':'').$repl_addresses;
-
-  # If the item is private, take into account the exclude-list.
-  if (db_result($result,0,'privacy') == '2')
-    {
-       $exclude_list = db_result(db_execute("SELECT ".ARTIFACT
-                                            ."_private_exclude_address
-                                            FROM groups WHERE group_id=?",
-                                            array($group_id)), 0,
-                                 ARTIFACT."_private_exclude_address");
-    }
-  # Disallow mail notification for an address, private or not.
-  if ($force_exclude_list)
-    {
-      if ($exclude_list)
-        $exclude_list .= ",".$force_exclude_list;
-      else
-        $exclude_list = $force_exclude_list;
-    }
-  sendmail_mail($from, $to, $subject, $body, group_getunixname($group_id),
-                ARTIFACT, $item_id, 0, 0, $exclude_list);
-  return true;
-}
-# CERN SPECIFIC (at least for now) END
 ?>
