@@ -139,11 +139,11 @@ function show_item_list ($result_arr,
            # If we are in digest mode, add the digest checkbox.
           if ($field_arr[$j] == "digest")
             {
-              # Dirty workaround to have boxes selected by default in the
-              # form_input.
               print '<td class="center">'
-                    . form_input("checkbox", "items_for_digest[]",
-                                 "$thisitem_id\" checked=\"checked") . "</td>\n";
+                . form_checkbox (
+                    "items_for_digest[]", 1, ['value' => $thisitem_id]
+                  )
+                . "</td>\n";
               continue;
             }
 
@@ -528,10 +528,7 @@ function show_item_history ($item_id,$group_id, $no_limit=false)
               print utils_format_date($value_id, 'natural');
             }
           else
-            {
-              # It's a text zone then display directly.
-               print markup_basic($value_id);
-            }
+            print markup_basic ($value_id);
 
            print '</td>
 <td class="smaller" align="center"><img src="'
@@ -550,10 +547,7 @@ function show_item_history ($item_id,$group_id, $no_limit=false)
               print utils_format_date($new_value_id, 'natural');
             }
           else
-            {
-              # It's a text zone then display directly.
-              print htmlspecialchars ($new_value_id);
-            }
+            print markup_basic ($new_value_id);
           print "</td>\n";
           print "</tr>\n";
         }
@@ -720,9 +714,11 @@ ORDER BY bug_fv_id DESC LIMIT 1",
       $status =
         $dstatus[$current_group_id . $tracker . $content[$key]['resolution_id']];
 
-      print '
-  <div class="' . get_priority_color($content[$key]['priority'],
-                                     $content[$key]['status_id']) . '">';
+      print '<div class=\''
+        . utils_get_priority_color (
+            $content[$key]['priority'], $content[$key]['status_id']
+          )
+        . "'>\n";
 
       # Ability to remove a dependency is only given to technician
       # level members of a project.
@@ -730,7 +726,7 @@ ORDER BY bug_fv_id DESC LIMIT 1",
         {
           print '<span class="trash"><a href="'
             . htmlentities ($_SERVER['PHP_SELF'])
-            . '?func=delete_dependancy&amp;item_id=' . $item_id
+            . '?func=delete_dependency&amp;item_id=' . $item_id
             . '&amp;item_depends_on=' . $current_item_id
             . '&amp;item_depends_on_artifact=' . $tracker . '">'
             . '<img src="' . $GLOBALS['sys_home'] . 'images/' . SV_THEME
