@@ -3,7 +3,7 @@
 #
 # Copyright (C) 2001-2002 Laurent Julliard, CodeX Team, Xerox
 # Copyright (C) 2003-2006 Mathieu Roy <yeupou--gnu.org>
-# Copyright (C) 2017, 2018 Ineiev
+# Copyright (C) 2017, 2018, 2022 Ineiev
 #
 # This file is part of Savane.
 #
@@ -22,22 +22,33 @@
 
 $is_admin_page='y';
 
-extract(sane_import('request', array('field', 'update_field')));
-extract(sane_import('post', array(
-  'post_changes', 'submit', 'reset',
-  'label', 'description',
-  'status', 'keep_history', 'mandatory_flag', 'place',
-  'form_transition_default_auth',
-  'show_on_add_members', 'show_on_add', 'show_on_add_nologin',
-  'n1', 'n2',
-)));
+extract(sane_import('request', ['name' => 'field', 'true' => 'update_field']));
+extract(sane_import('post',
+  [
+    'true' =>
+      [
+        'post_changes', 'submit', 'reset'
+      ],
+    'specialchars' => ['label', 'description'],
+    'digits' =>
+      [
+        ['status', 'keep_history', [0, 1]],
+        ['mandatory_flag', [0, 3]],
+        'place', 'n1', 'n2'
+      ],
+     'strings' =>
+       [
+         ['form_transition_default_auth', ['A', 'F']],
+         ['show_on_add','show_on_add_members',  ['1']],
+         ['show_on_add_logged', ['2']]
+       ]
+  ]
+));
 
-if (!($group_id && user_ismember($group_id,'A')))
-  {
-    if (!$group_id)
-      exit_no_group();
-    exit_permission_denied();
-  }
+if (!$group_id)
+  exit_no_group ();
+if (!user_ismember ($group_id, 'A'))
+  exit_permission_denied ();
 
 # Initialize global bug structures.
 trackers_init($group_id);
@@ -58,7 +69,7 @@ if ($post_changes)
              # Vote cannot be possible for non-logged in.
             if ($field == "vote")
               {
-                $show_on_add_nologin = 0;
+                $show_on_add_logged = 0;
                 $show_on_add_members = 1;
               }
           }
@@ -68,7 +79,7 @@ if ($post_changes)
             # if the field is required.
             $show_on_add_members = trackers_data_is_showed_on_add_members($field);
             $show_on_add = trackers_data_is_showed_on_add($field);
-            $show_on_add_nologin = trackers_data_is_showed_on_add_nologin($field);
+            $show_on_add_logged = trackers_data_is_showed_on_add_nologin($field);
           }
 
         # The additional possibility of differently treating non project
@@ -77,7 +88,7 @@ if ($post_changes)
         # the show_on_add field:
         # bit 1 set: show for logged in non project members
         # bit 2 set: show for non logged in users.
-        $show_on_add = $show_on_add | $show_on_add_nologin;
+        $show_on_add = $show_on_add | $show_on_add_logged;
 
         trackers_data_update_usage($field,
                                    $group_id,
@@ -113,8 +124,8 @@ if ($update_field)
     print '<form action="'.htmlentities ($_SERVER['PHP_SELF'])
           .'" method="post">';
     print '<input type="hidden" name="post_changes" value="y" />
-    <input type="hidden" name="field" value="'.htmlspecialchars($field).'" />
-    <input type="hidden" name="group_id" value="'.htmlspecialchars($group_id).'" />
+    <input type="hidden" name="field" value="' . $field . '" />
+    <input type="hidden" name="group_id" value="' . $group_id . '" />
     <h1>'
       ._("Field Label:").' ';
 
@@ -124,8 +135,8 @@ if ($update_field)
         # Only selectboxes can have values configured.
         $closetag .= '<p><span class="smaller">'
                     .utils_link($GLOBALS['sys_home'].ARTIFACT
-                                .'/admin/field_values.php?group='.$group
-                                .'&amp;list_value=1&amp;field='.$field,
+                                .'/admin/field_values.php?group=' . $group
+                                .'&amp;list_value=1&amp;field=' . $field,
                                 _("Jump to this field values"))."</span></p>\n";
       }
     # If it is a custom field let the user change the label and description.
@@ -182,7 +193,7 @@ if ($update_field)
 </select>';
         }
 
-    print "\n\n<p>&nbsp;</p><h2>"._("Access:").'</h2>';
+    print "\n\n<p>&nbsp;</p><h2>" . _("Access:") . "</h2>\n";
 
     # Set mandatory bit: if the field is special, meaning it is entered
     # by the system, or if it is "priority", assume the
@@ -211,89 +222,67 @@ if ($update_field)
     $checkbox_members = '';
     $checkbox_loggedin = '';
     $checkbox_anonymous = '';
-    if (!trackers_data_is_required($field))
+    $sh_add_mem = trackers_data_is_showed_on_add_members ($field);
+    $sh_add = trackers_data_is_showed_on_add ($field);
+    $sh_anon = trackers_data_is_showed_on_add_nologin ($field);
+    if (trackers_data_is_required ($field))
       {
-        # Some fields require specific treatment.
-        if ($field != "vote" && $field != "originator_email")
-          {
-            $checkbox_members =
-              '<input type="checkbox" title="'._("Show field to members")
-              .'" name="show_on_add_members" value="1"'
-              .(trackers_data_is_showed_on_add_members($field)?
-                ' checked="checked"':'')
-              .' />';
-            $checkbox_anonymous =
-              '<input type="checkbox" title="'
-              ._("Show field to logged-in users")
-              .'" name="show_on_add_nologin" value="2"'
-              .(trackers_data_is_showed_on_add_nologin($field)?
-                ' checked="checked"':'')
-              .' />';
-            $checkbox_loggedin =
-              '<input type="checkbox" title="'._("Show field to anonymous users")
-              .'" name="show_on_add" value="1"'
-              .(trackers_data_is_showed_on_add($field)?' checked="checked"':'')
-              .' />';
-          }
-        else
-          {
-            # Vote must be possible for members.
-            # Vote cannot be possible for non logged in.
-            if ($field != "vote")
-              {
-                $checkbox_members = '+';
-                $checkbox_anonymous = 0;
-                $checkbox_loggedin =
-                  '<input type="checkbox" name="show_on_add" value="1"'
-                  .(trackers_data_is_showed_on_add($field)?
-                    ' checked="checked"':'').' />';
-              }
-
-            # Originator email is, by the code, available only to
-            # anonymous.
-            if ($field != "vote")
-              {
-                $checkbox_members = 0;
-                $checkbox_loggedin = 0;
-                $checkbox_anonymous =
-                  '<input type="checkbox" name="show_on_add_nologin" value="2"'
-                  .(trackers_data_is_showed_on_add_nologin($field)?
-                    ' checked="checked"':'').' />';
-              }
-          }
+        # Do not let the user change these field settings.
+        if ($sh_add_mem)
+          $checkbox_members = '+';
+        if ($sh_add)
+          $checkbox_loggedin = '+';
+        if ($sh_anon)
+          $checkbox_anonymous = '+';
       }
     else
       {
-        # Do not let the user change these field settings.
-        if (trackers_data_is_showed_on_add_members($field))
+        # Some fields require specific treatment.
+        if ($field == "vote")
           {
+            # Vote is always available for members.
+            # Vote is impossible unless logged in.
             $checkbox_members = '+';
+            $checkbox_anonymous = 0;
+            $checkbox_loggedin = form_checkbox ("show_on_add", $sh_add);
           }
-        if (trackers_data_is_showed_on_add($field))
+        elseif ($field == "originator_email")
           {
-            $checkbox_loggedin = '+';
+            # Originator email is, by the code, available only to anonymous.
+            $checkbox_members = 0;
+            $checkbox_loggedin = 0;
+            $checkbox_anonymous =
+              form_checkbox ("show_on_add_logged", $sh_anon, ['value' => "2"]);
           }
-        if (trackers_data_is_showed_on_add_nologin($field))
+        else
           {
-            $checkbox_anonymous = '+';
+            $checkbox_members =
+              form_checkbox (
+                "show_on_add_members", $sh_add_mem,
+                ['title' => _("Show field to members")]
+              );
+            $checkbox_anonymous =
+              form_checkbox (
+                "show_on_add_logged", $sh_anon,
+                ['title' => _("Show field to logged-in users"), 'value' => "2"]
+              );
+            $checkbox_loggedin =
+              form_checkbox (
+                "show_on_add_members", $sh_add,
+                ['title' => _("Show field to anonymous users")]
+              );
           }
-      }
+      } # !trackers_data_is_required ($field)
 
       if ($checkbox_members)
-        {
-          print '<br />&nbsp;&nbsp;&nbsp;
-'.$checkbox_members.' '._("<!-- present this field to --> Project Members");
-        }
+        print "<br />\n&nbsp;&nbsp;&nbsp;$checkbox_members "
+          . _("<!-- present this field to --> Project Members");
       if ($checkbox_loggedin)
-        {
-          print '<br />&nbsp;&nbsp;&nbsp;
-'.$checkbox_loggedin.' '._("<!-- present this field to --> Logged-in Users");
-        }
+        print "<br />\n&nbsp;&nbsp;&nbsp;$checkbox_loggedin "
+          . _("<!-- present this field to --> Logged-in Users");
       if ($checkbox_anonymous)
-        {
-          print '<br />&nbsp;&nbsp;&nbsp;
-'.$checkbox_anonymous.' '._("<!-- present this field to --> Anonymous Users");
-        }
+        print "<br />\n&nbsp;&nbsp;&nbsp;$checkbox_anonymous "
+           . _("<!-- present this field to --> Anonymous Users");
 
       print "\n\n<p>&nbsp;</p>\n<h2>"._("Display:")."</h2>\n";
 
@@ -437,7 +426,7 @@ name="form_transition_default_auth" value="F" '
 
           $html = '<td><a href="'.htmlentities ($_SERVER['PHP_SELF'])
              .'?group_id='.$group_id
-             .'&update_field=1&field='.$field_name.'">'
+             .'&update_field=1&field=' . urlencode ($field_name) . '">'
              .trackers_data_get_label($field_name)."</a></td>\n"
              ."\n<td>".trackers_data_get_display_type_in_clear($field_name)
              .'</td>'."\n<td>".trackers_data_get_description($field_name)
