@@ -428,10 +428,11 @@ priority and open/close items"))) . "</p>\n";
             while ($canned = db_fetch_array($result_canned))
               {
                 print '&nbsp;&nbsp;&nbsp;';
-                print form_input("checkbox", "canned_response[]",
-                                 $canned['bug_canned_id']) . ' '
-                                 . $canned['title'];
-                print "<br />\n";
+                print form_checkbox (
+                        "canned_response[]", 0,
+                        ['value' => $canned['bug_canned_id']]
+                      );
+                print " {$canned['title']}<br />\n";
               }
             print "</div>\n";
           }
@@ -592,7 +593,7 @@ fill a dependency against):");
         print '</p>
 <p><span class="preinput">';
       printf (_("Please select a dependency to add in the result of your search
-of '%s' in the database:"), $depends_search);
+of '%s' in the database:"), htmlspecialchars ($depends_search));
         print '</span>';
 
         $success = false;
@@ -635,12 +636,13 @@ of '%s' in the database:"), $depends_search);
                       {
 # Right now only print id, summary and group.
 # We may change that depending on users feedback.
-                         print '<br />';
+                         print "<br />\n";
                          print '&nbsp;&nbsp;&nbsp;'
-                           . form_input("checkbox", "dependent_on_" . $tracker
-                                        . "[]", $res_id)
-                           . ' ' . $tracker . ' #' . $res_id . ': '
-                           . $res_summary;
+                           . form_checkbox (
+                               "dependent_on_{$tracker}[]", 0,
+                               ['value' => $res_id]
+                             )
+                           . " $tracker # $res_id: $res_summary";
                          print ', ' . _("group") . ' '
                            . group_getname($res_group);
                       }
@@ -794,11 +796,11 @@ managers.") . '</p>
 # Search results, if we are already at step 2 of filling.
         if ($reassign_change_project_search)
           {
-            print '</p>
+            print '
 <p><span class="preinput">';
             printf (_("To which project this bug should be reassigned to? This is
 the result of your search of '%s' in the database:"),
-                    $reassign_change_project_search);
+                    htmlspecialchars ($reassign_change_project_search));
             print '</span>';
 
 # Print a null-option, someone may change his mine without having
@@ -847,7 +849,7 @@ than three characters are valid.");
       . form_submit(_("Submit Changes and Browse Items"), "submit", 'class="bold"')
       . ' '
       . form_submit(_("Submit Changes and Return to this Item"), "submitreturn")
-      . "</form></div>\n";
+      . "</div>\n</form>\n";
 
     print "<p>&nbsp;</p><p>&nbsp;</p>\n";
     print html_hidsubpart_header("history", _("History"));
