@@ -186,18 +186,21 @@ function user_getname($user_id=0, $getrealname=0)
   return $USER_NAMES[$prefix."_$user_id"];
 }
 
-function user_getid($username=0)
+function user_getid  ($username = 0)
 {
   if (!$username)
     {
       # No username, return info for the current user.
       global $G_USER;
-      return ($G_USER?$G_USER['user_id']:0);
+      if ($G_USER)
+        return $G_USER['user_id'];
+      return 0;
     }
   $result = db_execute("SELECT user_id FROM user WHERE user_name=?",
                        array($username));
   if ($result and db_numrows($result) > 0)
     return db_result($result,0,"user_id");
+  return 0;
 }
 
 function user_exists($user_id, $squad_only=false)
@@ -252,33 +255,28 @@ function user_get_field ($user_id, $field)
   return false;
 }
 
-function user_get_result_set($user_id)
+# Fetch a row from user table by user_id unless already cached,
+# put it to $USER_RES[$user_id].
+function user_get_result_set ($user_id)
 {
-  # Create a common set of user result sets,
-  # so it doesn't have to be fetched each time.
   global $USER_RES;
-  if (empty($USER_RES["_".$user_id."_"]))
-    {
-      $USER_RES["_".$user_id."_"]=db_execute("SELECT * FROM user WHERE user_id=?",
-                                             array($user_id));
-      return $USER_RES["_".$user_id."_"];
-    }
-  return $USER_RES["_".$user_id."_"];
+  if (empty ($user_id))
+    return null;
+  if (empty ($USER_RES[$user_id]))
+    $USER_RES[$user_id] =
+      db_execute ("SELECT * FROM user WHERE user_id = ?", [$user_id]);
+  return $USER_RES[$user_id];
 }
 
-function user_get_result_set_from_unix($user_name)
+# Fetch a row from user table by user_name, put it to $USER_RES[$user_id].
+function user_get_result_set_from_user_name ($user_name)
 {
-  # Create a common set of user result sets,
-  # so it doesn't have to be fetched each time.
   global $USER_RES;
-  $res = db_execute("SELECT * FROM user WHERE user_name=?", array($user_name));
-  if (db_numrows($res))
-    {
-      $user_id = db_result($res,0,'user_id');
-      $USER_RES["_".$user_id."_"] = $res;
-      return $USER_RES["_".$user_id."_"];
-    }
-  return null;
+  $res = db_execute ("SELECT * FROM user WHERE user_name = ?", [$user_name]);
+  if (!($res && db_numrows ($res)))
+    return null;
+  $USER_RES[db_result ($res, 0, 'user_id')] = $res;
+  return $res;
 }
 
 function user_get_timezone()
