@@ -33,19 +33,10 @@ define('FB_ERROR', 1);
 # Get path for site-specific content.
 function utils_get_content_filename ($file)
 {
-  if (is_file($GLOBALS['sys_incdir'].'/php/'.$file.'.php'))
-    return $GLOBALS['sys_incdir'].'/php/'.$file.'.php';
-  if (is_file($GLOBALS['sys_incdir'].'/php/'.$file.'.txt'))
-    return $GLOBALS['sys_incdir'].'/php/'.$file.'.txt';
-# Fallback to legacy location.
-  if (isset ($GLOBALS['locale']))
-    {
-      if (is_file($GLOBALS['sys_incdir'].'/'.$file.'.'.$GLOBALS['locale']))
-        # There is a localized version of the file:
-        return $GLOBALS['sys_incdir'].'/'.$file.'.'.$GLOBALS['locale'];
-    }
-  if (is_file($GLOBALS['sys_incdir'].'/'.$file.'.txt'))
-    return $GLOBALS['sys_incdir'].'/'.$file.'.txt';
+  $f = $GLOBALS['sys_incdir'] . '/php/' . $file . '.php';
+
+  if (is_file($f))
+    return $f;
   return null;
 }
 
@@ -55,10 +46,6 @@ function utils_get_content ($filename)
   $file = utils_get_content_filename($filename);
   if ($file != null)
     include($file);
-  else
-    fb(sprintf(_("Warning: Savane was not able to read site-specific
-information from file '%s', please contact administrators"),
-       $filename), 1);
 }
 
 # Make sure that to avoid malicious file paths.
@@ -226,17 +213,6 @@ function utils_cutstring ($string, $length=35)
   return $string;
 }
 
-# Same as the previous but is used for links and does not try to cut
-# because it annoys users who can't safely.
-# copy/paste a complete paragraph with the links intact (check
-# 105807@sv).
-function utils_cutlink ($string, $length=35)
-{
-  $url = $string;
-  unset($help);
-  return '<a href="'.$url.'">'.$string.'</a>';
-}
-
 # Return a formatted date for a unix timestamp.
 #
 # The given unix timestamp will be formatted according to
@@ -701,11 +677,6 @@ function show_priority_colors_key()
   print  "</p>\n";
 }
 
-function get_priority_color ($index, $closed="")
-{
-  return utils_get_priority_color($index, $closed);
-}
-
 function utils_get_tracker_icon ($tracker)
 {
   if ($tracker == "bugs")
@@ -728,31 +699,21 @@ function utils_get_tracker_prefix ($tracker)
   return $tracker;
 }
 
-# Return the translation for the given tracker, if available.
+# Return the localized name for the given tracker, if available.
 # Otherwise, return the input string.
-function utils_get_tracker_name($tracker)
+function utils_get_tracker_name ($tracker)
 {
-  switch ($tracker)
-    {
-      case 'bugs':
-        $name = _('bugs');
-        break;
-      case 'cookbook':
-        $name = _('recipes');
-        break;
-      case 'patch':
-        $name = _('patches');
-        break;
-      case 'support':
-        $name = _('support requests');
-        break;
-      case 'task':
-        $name = _('tasks');
-        break;
-      default:
-        $name = $tracker;
-    }
-  return $name;
+  if ($tracker == 'bugs')
+    return _('bugs');
+  if ($tracker == 'cookbook')
+    return _('recipes');
+  if ($tracker == 'patch')
+    return _('patches');
+  if ($tracker == 'support')
+    return _('support requests');
+  if ($tracker == 'task')
+    return _('tasks');
+  return $tracker;
 }
 
 function utils_get_priority_color ($index, $closed="")
