@@ -21,10 +21,10 @@
 require_once('../include/init.php');
 require_once('../include/http.php');
 require_once('../include/sane.php');
-header('Content-Type: text/javascript');
-extract(sane_import('request', array('suffix')));
+header ('Content-Type: text/javascript');
+extract (sane_import ('request', ['preg' => [['suffix', '/^\w*$/']]]));
 
-if (preg_match('/\W/', $suffix))
+if ($suffix === null)
   $suffix = "";
 
 print
